==> haskell-wai-cors-0.2.6-59-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-4AA2Ufxe5O45PeRIqLtwNH
key: wai-cors-0.2.6-4AA2Ufxe5O45PeRIqLtwNH
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
abi: 8e3159a913d636ffe5bf244491f63a23
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-4AA2Ufxe5O45PeRIqLtwNH
depends:
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz
    wai-3.2.1.2-C1NXINF5Asz4Xltxrsh4qv mtl-2.2.2 transformers-0.5.5.0
abi-depends: attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi=317c5ffff2937e1007e568a75e4649c6
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz=83a424f80f062f589a336c1b654188f8
             wai-3.2.1.2-C1NXINF5Asz4Xltxrsh4qv=c78051ce3bf4822fdb7b0e21c322f844
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.6-60-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-156ORde32uT2X9Ndmz92Qu
key: wai-cors-0.2.6-156ORde32uT2X9Ndmz92Qu
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
abi: 444b586b8ccb02b680a235f13aa9776d
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-156ORde32uT2X9Ndmz92Qu
depends:
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH
    wai-3.2.1.2-67RI6tsTihE3bpOD5z1U4j mtl-2.2.2 transformers-0.5.5.0
abi-depends: attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi=317c5ffff2937e1007e568a75e4649c6
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH=b88dec2e9e51949b7c6a738f8b360494
             wai-3.2.1.2-67RI6tsTihE3bpOD5z1U4j=955367f60c95b74086a396efde812133
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
